// SPDX-License-Identifier: GPL-2.0-only
/*
 * Copyright (C) 2021 Marton Borzak <hello@martonborzak.com>
 * Derived from ld9040 AMOLED LCD backlight driver from
 * drivers/video/backlight/ld9040_gamma.h
 * 
 * Gamma level definitions.
 *
 * Copyright (c) 2011 Samsung Electronics
 * InKi Dae <inki.dae@samsung.com>
 * Donghwa Lee <dh09.lee@samsung.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
*/

#ifndef _AMS326PM01_BRIGHTNESS_H
#define _AMS326PM01_BRIGHTNESS_H

#define MAX_GAMMA_LEVEL	11
#define GAMMA_TABLE_COUNT	21

static const unsigned int ams326pm01_gamma_commands[] = {
	0x60, 0x61, 0x62, 0x63, 0x64, 0x65, 0x66, 0x67,
    0x68, 0x69, 0x6a, 0x6b, 0x6c, 0x6d, 0x6e, 0x6f, 
    0x70, 0x71, 0x72, 0x73, 0x74
};

static const unsigned int ams326pm01_gamma_330[] = {
	0x00, 0xa8, 0xc4, 0xdb, 0xbc, 0xc7, 0x6f, 0x00,
    0x9a, 0xc1, 0xdb, 0xb9, 0xc7, 0x6e, 0x00, 0x8c, 
    0xdb, 0xd8, 0xb2, 0xc3, 0xa7
};

static const unsigned int ams326pm01_gamma_300[] = {
	0x00, 0xa7, 0xc4, 0xdc, 0xbe, 0xc7, 0x68, 0x00,
    0x97, 0xc2, 0xdb, 0xbc, 0xc6, 0x67, 0x00, 0x8c, 
    0xbd, 0xd9, 0xb5, 0xc3, 0x9e
};

static const unsigned int ams326pm01_gamma_270[] = {
	0x00, 0xa9, 0xc6, 0xdc, 0xc0, 0xc9, 0x61, 0x00,
    0x99, 0xc3, 0xdb, 0xbe, 0xc8, 0x60, 0x00, 0x8c, 
    0xbe, 0xd9, 0xb6, 0xc5, 0x96
};

static const unsigned int ams326pm01_gamma_240[] = {
	0x00, 0xac, 0xc5, 0xdd, 0xc1, 0xcb, 0x58, 0x00,
    0x9b, 0xc2, 0xdc, 0xbf, 0xca, 0x57, 0x00, 0x8d, 
    0xbe, 0xda, 0xb7, 0xc7, 0x8b
};

static const unsigned int ams326pm01_gamma_210[] = {
	0x00, 0xae, 0xc6, 0xde, 0xc2, 0xcd, 0x50, 0x00,
    0x99, 0xc4, 0xdc, 0xc0, 0xcd, 0x4e, 0x00, 0x8d, 
    0xbf, 0xda, 0xb9, 0xc9, 0x81
};

static const unsigned int ams326pm01_gamma_180[] = {
	0x00, 0xad, 0xc8, 0xde, 0xc6, 0xcd, 0x47, 0x00,
    0x99, 0xc6, 0xdc, 0xc5, 0xcc, 0x45, 0x00, 0x8d, 
    0xc1, 0xda, 0xbd, 0xc9, 0x76
};

static const unsigned int ams326pm01_gamma_150[] = {
	0x00, 0xad, 0xc9, 0xdf, 0xc6, 0xd2, 0x3c, 0x00,
    0x9a, 0xc6, 0xde, 0xc4, 0xd1, 0x3a, 0x00, 0x8f,
    0xc1, 0xdb, 0xbd, 0xce, 0x69
};

static const unsigned int ams326pm01_gamma_120[] = {
	0x00, 0xae, 0xca, 0xe0, 0xca, 0xd7, 0x33, 0x00,
    0x9a, 0xc8, 0xde, 0xc6, 0xd4, 0x30, 0x00, 0x8f,
    0xc3, 0xdc, 0xc1, 0xce, 0x5f
};

static const unsigned int ams326pm01_gamma_90[] = {
	0x00, 0xaf, 0xcb, 0xe0, 0xcc, 0xd7, 0x28, 0x00,
    0x9b, 0xca, 0xe0, 0xc8, 0xd6, 0x26, 0x00, 0x91,
    0xc3, 0xdd, 0xc1, 0xd2, 0x53
};

static const unsigned int ams326pm01_gamma_60[] = {
	0x00, 0xb0, 0xcc, 0xe1, 0xce, 0xdc, 0x1f, 0x00,
    0x9c, 0xcc, 0xe0, 0xca, 0xd8, 0x28, 0x00, 0x93,
    0xc5, 0xde, 0xc3, 0xd6, 0x46
};

static const unsigned int ams326pm01_gamma_0[] = {
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00
};

struct ams326pm01_gamma {
	unsigned int *gamma_table[MAX_GAMMA_LEVEL];
};

static struct ams326pm01_gamma gamma_table = {
    .gamma_table[0] = (unsigned int *)&ams326pm01_gamma_0,
    .gamma_table[1] = (unsigned int *)&ams326pm01_gamma_60,
    .gamma_table[2] = (unsigned int *)&ams326pm01_gamma_90,
    .gamma_table[3] = (unsigned int *)&ams326pm01_gamma_120,
	.gamma_table[4] = (unsigned int *)&ams326pm01_gamma_150,
	.gamma_table[5] = (unsigned int *)&ams326pm01_gamma_180,
	.gamma_table[6] = (unsigned int *)&ams326pm01_gamma_210,
	.gamma_table[7] = (unsigned int *)&ams326pm01_gamma_240,
	.gamma_table[8] = (unsigned int *)&ams326pm01_gamma_270,
	.gamma_table[9] = (unsigned int *)&ams326pm01_gamma_300,
	.gamma_table[10] = (unsigned int *)&ams326pm01_gamma_330,
};

#endif
